Update language to comply with Android's inclusive language guidance

See https://source.android.com/setup/contribute/respectful-code for
reference

BUG=162536543
Test: m

Change-Id: I0190988e08fcdade2d1644300409f8f810ddf62c
diff --git a/support/java/src/androidx/renderscript/RenderScript.java b/support/java/src/androidx/renderscript/RenderScript.java
index 10836d9..5569fe4 100644
--- a/support/java/src/androidx/renderscript/RenderScript.java
+++ b/support/java/src/androidx/renderscript/RenderScript.java
@@ -63,7 +63,7 @@
     private Context mApplicationContext;
     private String mNativeLibDir;
 
-    static private String mBlackList = "";
+    static private String mDenyList = "";
      /**
      * Sets the denylist of Models to only use support lib runtime.
      * Should be used before context create.
@@ -72,11 +72,11 @@
      *
      * Format: "(MANUFACTURER1:PRODUCT1:MODEL1), (MANUFACTURER2:PRODUCT2:MODEL2)..."
      * e.g. : To Denylist Nexus 7(2013) and Nexus 5.
-     *        mBlackList = "(asus:razor:Nexus 7), (LGE:hammerhead:Nexus 5)";
+     *        mDenyList = "(asus:razor:Nexus 7), (LGE:hammerhead:Nexus 5)";
      */
-    static public void setBlackList(String blackList) {
-        if (blackList != null) {
-            mBlackList = blackList;
+    static public void setDenyList(String denyList) {
+        if (denyList != null) {
+            mDenyList = denyList;
         }
     }
      /**
@@ -225,7 +225,7 @@
 
         if (sNative == 1) {
             // check against the denylist
-            if (mBlackList.length() > 0) {
+            if (mDenyList.length() > 0) {
                 String deviceInfo = '(' +
                                     android.os.Build.MANUFACTURER +
                                     ':' +
@@ -233,7 +233,7 @@
                                     ':' +
                                     android.os.Build.MODEL +
                                     ')';
-                if (mBlackList.contains(deviceInfo)) {
+                if (mDenyList.contains(deviceInfo)) {
                     sNative = 0;
                     return false;
                 }
diff --git a/support/java/src/androidx/renderscript/Script.java b/support/java/src/androidx/renderscript/Script.java
index 49c0039..1dcbe3b 100644
--- a/support/java/src/androidx/renderscript/Script.java
+++ b/support/java/src/androidx/renderscript/Script.java
@@ -42,17 +42,17 @@
     long getDummyAlloc(Allocation ain) {
         long dInElement = 0;
         long dInType = 0;
-        long dummyAlloc = 0;
+        long placeholderAlloc = 0;
         if (ain != null) {
             Type inType = ain.getType();
             dInElement = inType.getElement().getDummyElement(mRS);
             dInType = inType.getDummyType(mRS, dInElement);
             int xBytesSize = inType.getX() * inType.getElement().getBytesSize();
-            dummyAlloc = mRS.nIncAllocationCreateTyped(ain.getID(mRS), dInType, xBytesSize);
-            ain.setIncAllocID(dummyAlloc);
+            placeholderAlloc = mRS.nIncAllocationCreateTyped(ain.getID(mRS), dInType, xBytesSize);
+            ain.setIncAllocID(placeholderAlloc);
         }
 
-        return dummyAlloc;
+        return placeholderAlloc;
     }
     /**
      * KernelID is an identifier for a Script + root function pair. It is used
diff --git a/tests/java_api/RSUnitTests/supportlibonlysrc/com/android/rs/unittest/apitest.rscript b/tests/java_api/RSUnitTests/supportlibonlysrc/com/android/rs/unittest/apitest.rscript
index b0829a3..4e2dd4f 100644
--- a/tests/java_api/RSUnitTests/supportlibonlysrc/com/android/rs/unittest/apitest.rscript
+++ b/tests/java_api/RSUnitTests/supportlibonlysrc/com/android/rs/unittest/apitest.rscript
@@ -132,7 +132,7 @@
 rs_matrix3x3 m3x3;
 rs_matrix4x4 m4x4;
 
-int RS_KERNEL dummyKernel(int v) { return v; }
+int RS_KERNEL testKernel(int v) { return v; }
 
 // This function just checks that all of the called functions are
 // able to be linked. It is not intended to be executed!
@@ -1137,7 +1137,7 @@
     rsSendToClientBlocking(0);
     rsSendToClientBlocking(0, NULL, 0);
 
-    rsForEach(dummyKernel, allocNonNull, allocNonNull);
+    rsForEach(testKernel, allocNonNull, allocNonNull);
 
     // rs_debug.rsh
     rsDebug("", f);
diff --git a/tests/java_api/RSUnitTests/supportlibsrc_gen/com/android/rs/unittest/apitest.rscript b/tests/java_api/RSUnitTests/supportlibsrc_gen/com/android/rs/unittest/apitest.rscript
index 28f6c8f..2ebdf7a 100644
--- a/tests/java_api/RSUnitTests/supportlibsrc_gen/com/android/rs/unittest/apitest.rscript
+++ b/tests/java_api/RSUnitTests/supportlibsrc_gen/com/android/rs/unittest/apitest.rscript
@@ -134,7 +134,7 @@
 rs_matrix3x3 m3x3;
 rs_matrix4x4 m4x4;
 
-int RS_KERNEL dummyKernel(int v) { return v; }
+int RS_KERNEL testKernel(int v) { return v; }
 
 // This function just checks that all of the called functions are
 // able to be linked. It is not intended to be executed!
@@ -1139,7 +1139,7 @@
     rsSendToClientBlocking(0);
     rsSendToClientBlocking(0, NULL, 0);
 
-    rsForEach(dummyKernel, allocNonNull, allocNonNull);
+    rsForEach(testKernel, allocNonNull, allocNonNull);
 
     // rs_debug.rsh
     rsDebug("", f);
diff --git a/tests/java_api/Refocus/src/com/android/rs/test/layered_filter_fast_d1new.rscript b/tests/java_api/Refocus/src/com/android/rs/test/layered_filter_fast_d1new.rscript
index 750e4ee..9a63ac6 100644
--- a/tests/java_api/Refocus/src/com/android/rs/test/layered_filter_fast_d1new.rscript
+++ b/tests/java_api/Refocus/src/com/android/rs/test/layered_filter_fast_d1new.rscript
@@ -30,7 +30,6 @@
 // UnpackInputImage, ComputeLayerMatteBehindFocalDepth, ComputeIntegralImageForLayerBehindFocalDepth,
 // FilterLayerBehindFocalDepth, updateSharpImageUsingFuzzyImage, ComputeLayerMatteInFrontOfFocalDepth,
 // FilterLayerInFrontOfFocalDepth
-// double cpuDummy;
 
 // Image size of padded images: g_sharp_image and g_fuzzy_image.
 // Float4 that stores the image size info: 1. width, 2. height, 3. margin
diff --git a/tests/lldb/README.txt b/tests/lldb/README.txt
index 9c07494..70e93bc 100644
--- a/tests/lldb/README.txt
+++ b/tests/lldb/README.txt
@@ -42,7 +42,7 @@
                               [--run-emu]
                               [--adb-path ADB_PATH]
                               [--aosp-product-path AOSP_PRODUCT_PATH]
-                              [--blacklist BLACKLIST [BLACKLIST ...]]
+                              [--blocklist BLOCKLIST [BLOCKLIST ...]]
                               [--device-port DEVICE_PORT]
                               [--emu-cmd EMU_CMD]
                               [--host-port HOST_PORT]
@@ -75,10 +75,10 @@
           --adb-path ADB_PATH   Path to android debug bridge on the host.
           --aosp-product-path AOSP_PRODUCT_PATH
                                 The path to the "out" folder of the AOSP repository.
-          --blacklist BLACKLIST [BLACKLIST ...]
-                                Provide a test blacklist for skipping specific tests.
-                                To specify the blacklist from the command line the
-                                following can be used: --blacklist test1.py test2.py
+          --blocklist BLOCKLIST [BLOCKLIST ...]
+                                Provide a test blocklist for skipping specific tests.
+                                To specify the blocklist from the command line the
+                                following can be used: --blocklist test1.py test2.py
                                 ...
           --device-port DEVICE_PORT
                                 Specify the port number that lldb-server (on the
diff --git a/tests/lldb/run_tests.py b/tests/lldb/run_tests.py
index cd78cec..d1700bb 100755
--- a/tests/lldb/run_tests.py
+++ b/tests/lldb/run_tests.py
@@ -174,7 +174,7 @@
             config = Config()
 
         # save the test denylist
-        self.blacklist = _choice(args.blacklist, config.blacklist)
+        self.blocklist = _choice(args.blocklist, config.blocklist)
 
         # Allow any of the command line arguments to override the
         # values in the config file.
@@ -722,7 +722,7 @@
                 for item in os.listdir(current_test_dir):
                     if (item.startswith('test')
                         and item.endswith('.py')
-                        and not item in state.blacklist):
+                        and not item in state.blocklist):
                         tests.append(item)
     else:
         if single_test.endswith('.py'):
diff --git a/tests/lldb/config.py b/tests/lldb/config.py
index a72b80b..bc478d0 100644
--- a/tests/lldb/config.py
+++ b/tests/lldb/config.py
@@ -82,11 +82,11 @@
         return 'lldb'
 
     @property
-    def blacklist(self):
-        '''Provide a test blacklist for skipping specific tests.
+    def blocklist(self):
+        '''Provide a test blocklist for skipping specific tests.
 
         To specify the blacklist from the command line the following can be
         used: --blacklist test1.py test2.py ...'''
         return []
 
     @property
@@ -82,11 +82,11 @@
 
-        To specify the blacklist from the command line the following can be
-        used: --blacklist test1.py test2.py ...'''
+        To specify the blocklist from the command line the following can be
+        used: --blocklist test1.py test2.py ...'''
         return []
 